<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml"
	    encoding="utf-8"
	    doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	    indent="yes"/>
<!-- parametres :
	@buildDate : date d'invocation
-->
<xsl:param name="buildDate">--/--/---- --:--</xsl:param>
<xsl:param name="root">.</xsl:param>
<xsl:param name="pageId">undef page</xsl:param>
<xsl:param name="hasToc"><xsl:value-of select="count(/document/toc)"/></xsl:param>

<!--********************************************
	Structures de base
-->	
<xsl:template match="para|p">
    <p><xsl:apply-templates/></p>
</xsl:template>
<xsl:template match="a|b|i|u|pre|br|img|sub|table|tr|td|th|li|ul">
	<xsl:copy-of select="."/>
</xsl:template>	
<xsl:template match="icode">
	<code><xsl:apply-templates/></code>
</xsl:template>	
<!--******************************
	Boite/cadre
-->
<xsl:template match="box|note">
	<div class="box"><xsl:apply-templates/></div>
</xsl:template>
<xsl:template match="code">
  	<div class="code">
		<xsl:if test="@title!=''">
			<p><xsl:value-of select="@title"/></p>
		</xsl:if>
		<pre><xsl:apply-templates select="*|text()"/></pre>
	</div>	
</xsl:template>

<!--******************************
	inclusion d'un fichier texte
-->
<xsl:template match="text">
<pre>
include(<xsl:value-of select="@src"/>.txt)
</pre>
</xsl:template>
<!--******************************
	enumeration
-->	
<xsl:template match="enum">
	<xsl:if test="name(preceding-sibling::*[1])!='enum'">
		<xsl:apply-templates mode="acc" select="."/>
	</xsl:if>
</xsl:template>	
<!-- accumulation -->
<xsl:template match="enum" mode="acc">
	<xsl:param name="acc"/>
	<xsl:choose>
		<xsl:when test="name(following-sibling::*[1])!='enum'">
			<xsl:call-template name="enumEnd">
				<xsl:with-param name="acc">
					<xsl:copy-of select="$acc"/>
					<xsl:apply-templates mode="ok" select="."/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="following-sibling::*[1]" mode="acc">
				<xsl:with-param name="acc">
					<xsl:copy-of select="$acc"/>
					<xsl:apply-templates mode="ok" select="."/>
				</xsl:with-param>
			</xsl:apply-templates>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<!-- ok -->
<xsl:template match="enum" mode="ok">
	<li><xsl:apply-templates/></li>
</xsl:template>
<!-- copier le resultat indent -->
<xsl:template name="enumEnd">
	<xsl:param name="acc"/>
	<ul>
		<xsl:copy-of select="$acc"/>
	</ul>
</xsl:template>
<!--***********************************************
	Figure
-->
<xsl:template match="fig">
	<div class="fig">
		<xsl:choose>
			<xsl:when test="substring(@src,string-length(@src)-3)='.svg'">
				<object type="image/svg+xml" data="{@src}">
				<p>SVG non pris en charge par le navigateur, cliquer sur le lien ci dessous pour tlcharger le fichier.</p>
			</object>
			<br/><a href="{@src}"><xsl:value-of select="@title"/></a>
			</xsl:when>
			<xsl:otherwise>
	<img src="{@src}" alt="{@title}"/><br/>
	<xsl:value-of select="@title"/>
			</xsl:otherwise>
		</xsl:choose>	
	</div>
</xsl:template>
<!--***********************************************
	References
-->
<xsl:template match="references">
	<div class="references">
	<xsl:apply-templates select="ref" mode="detail"/>
	</div>
</xsl:template>
<xsl:template match="ref" mode="detail">
	<div class="refentry" id="ref.{@id}">
		<a name="ref.{@id}">[<xsl:value-of select="@id"/>]</a> : 
		<xsl:value-of select="author"/>
		<xsl:text> </xsl:text>
		<i>"<xsl:value-of select="title"/>"</i>
		<xsl:text> </xsl:text>
		<xsl:value-of select="edition"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="date"/>
		<xsl:apply-templates select="href" mode="refDetail"/>
	</div>
</xsl:template>
<xsl:template match="ref">
	<a href="#ref.{@id}" class="reflink">[<xsl:value-of select="@id"/>]</a>
</xsl:template>
<!--***********************************************
	Auteur
-->
<xsl:template match="author" mode="refDetail">
	<xsl:apply-templates/><xsl:text>, </xsl:text>
</xsl:template>
<!--***********************************************
	URL
-->
<xsl:template match="href" mode="refDetail">
	<br/><a target="_top">
		<xsl:attribute name="href"><xsl:value-of select="."/></xsl:attribute>
		<xsl:apply-templates/>
	</a>
</xsl:template>	
<!--***********************************************
	Gestion des exigences
-->
<xsl:template match="replacedby">
  <xsl:text>, </xsl:text><xsl:value-of select="@id"/>
</xsl:template>
<xsl:template match="rq">
	<xsl:variable name="rid"><xsl:value-of select="@id"/></xsl:variable>
	<xsl:apply-templates select="/document/requirements/rq[@id = $rid]" mode="rqDetail"/>
</xsl:template>
<xsl:template match="rq" mode="rqDetail">
	<div class="rq">
	<table><tr>
  <xsl:choose>
  <xsl:when test="@status='obsolete'">
		<td><b><xsl:value-of select="@id"/></b><br/>
		<b>Obsolte :</b><br/>
		remplac par<xsl:apply-templates select="replacedby"/>
		</td>
  </xsl:when>
  <xsl:otherwise>
		<td><b><xsl:value-of select="@id"/></b></td>
		<td><xsl:apply-templates/></td>
  </xsl:otherwise>
  </xsl:choose>	
  </tr><tr><td></td><td>
	<i><xsl:apply-templates select="cover" mode="expand"/></i>
  </td></tr></table>
	</div>
</xsl:template>
<xsl:template match="cover"/>
<xsl:template match="cover" mode="expand">
<xsl:value-of select="@rq"/><xsl:text> </xsl:text>
</xsl:template>
<xsl:template match="rq" mode="forward-matrix">
<tr>
	<td><xsl:value-of select="@id"/></td>
	<td><xsl:apply-templates select="cover" mode="expand"/></td>
</tr>	
</xsl:template>
<xsl:template match="rq" mode="reverse-matrix">
<xsl:value-of select="@id"/><xsl:text> </xsl:text>
</xsl:template>
<!-- matrice traabilit -->
<xsl:template match="rqmatrix">
	<div class="rqmatrix">
	<table>
		<xsl:for-each select="/document/requirements/rq/cover">
			<xsl:sort select="@rq"/>
			<tr>
				<td><xsl:value-of select="@rq"/></td>
				<td>
					<xsl:variable name="rrq"><xsl:value-of select="@rq"/></xsl:variable>
					<xsl:apply-templates 
						select="/document/requirements/rq/cover[@rq = $rrq]/.."
						mode="reverse-matrix"/>
				</td>
			</tr>
		</xsl:for-each>
	</table>	
	</div>
	<div class="rqmatrix">
	<table>
	<xsl:apply-templates select="/document/requirements/rq"
		mode="forward-matrix"/>
	</table>	
	</div>
</xsl:template>
<!--***********************************************
	copie "bete" du contenu d'un bloc xhtml
-->
<xsl:template match="xhtml">
	<xsl:copy-of select="./*"/>
</xsl:template>	
<!--************************************************
	Resum/Description de page
-->
<xsl:template match="abstract">
	<meta name="description">
		<xsl:attribute name="content"><xsl:apply-templates/></xsl:attribute>
	</meta>
</xsl:template>
<xsl:template match="abstract" mode="show">
	<div class="abstract">
	<h2>Rsum</h2>
	<p><xsl:apply-templates/></p>
	</div>
</xsl:template>
<xsl:template match="keywords" mode="show">
	<div class="keywords">
	<h2>Mots-cls</h2>
	<p><xsl:apply-templates/></p>
	</div>
</xsl:template>
<!--************************************************
	mots cls
-->
<xsl:template match="keywords">
	<meta name="keywords">
		<xsl:attribute name="content"><xsl:apply-templates/></xsl:attribute>
	</meta>
</xsl:template>
<!--************************************************
	tete de section
		$id id de la section
		$title titre de la section
		$level niveau de section
-->
<xsl:template name="sectionHead">
	<xsl:param name="id">none</xsl:param>
	<xsl:param name="title"></xsl:param>
	<xsl:param name="level">2</xsl:param>
	<div class="section-head">
	<xsl:choose>
		<xsl:when test="$title=''">&#160;</xsl:when>
		<xsl:otherwise>
			<xsl:element name="h{$level}">
				<xsl:if test="$id!='none'">
					<a name="{$id}"><xsl:value-of select="$id"/></a>
				</xsl:if>
				<xsl:if test="$hasToc!=0">
				<a><xsl:attribute name="name">
					<xsl:number count="section" level="multiple" format="1.1"/>
				</xsl:attribute></a>
				<a href="#top">
					<xsl:number count="section" level="multiple" format="1.1"/></a>&#160;
				</xsl:if>	
				<xsl:value-of select="$title"/>
			</xsl:element>	
		</xsl:otherwise>
	</xsl:choose>
	</div>
</xsl:template>
<!--************************************************
	Contenu d'une section
		$content contenu de la section
-->
<xsl:template name="sectionContent">
	<xsl:param name="content">
		<xsl:copy-of select="p|para|pre|xhtml|indent|enum|split|fig|summary|box|note|ref"/>
	</xsl:param>
	<xsl:if test="count($content)!=0">
	<div class="section-body">
		<xsl:apply-templates select="p|para|pre|xhtml|indent|enum|split|fig|summary|box|note|ref"/>
	</div>
	</xsl:if>
</xsl:template>
<!--************************************************
	Prise en charge d'une section
-->	
<xsl:template match="section">
	<div class="section">
	<xsl:choose>
		<xsl:when test="count(ancestor::chapter)&gt;0">
			<xsl:call-template name="sectionHead">
				<xsl:with-param name="id"><xsl:number level="multiple" count="section|article"/></xsl:with-param> 
				<xsl:with-param name="title"><xsl:value-of select="@title"/></xsl:with-param> 
				<xsl:with-param name="level"><xsl:value-of select="count(ancestor-or-self::section)+count(ancestor-or-self::article)+1"/></xsl:with-param> 
			</xsl:call-template>	
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="sectionHead">
				<xsl:with-param name="title"><xsl:value-of select="@title"/></xsl:with-param> 
				<xsl:with-param name="level"><xsl:value-of select="count(ancestor-or-self::section)+count(ancestor-or-self::article)+1"/></xsl:with-param> 
			</xsl:call-template>	
		</xsl:otherwise>
	</xsl:choose>
	<xsl:apply-templates/>
	</div>
</xsl:template>
<!--****************************************************
	Table des matires
-->
<xsl:template match="section" mode="summary">
	<xsl:param name="chapterFile"></xsl:param>
	<li><a><xsl:attribute name="href"><xsl:value-of select="$chapterFile"/>#<xsl:number count="section" level="multiple" format="1.1"/>
			</xsl:attribute>
		<xsl:number count="section" level="multiple" format="1.1"/>&#160;
		<xsl:value-of select="@title"/></a>
	<xsl:if test="count(section)&gt;0">
		<ul>
			<xsl:apply-templates select="section" mode="summary">
				<xsl:with-param name="chapterFile"><xsl:value-of select="$chapterFile"/></xsl:with-param>
			</xsl:apply-templates>
		</ul>
	</xsl:if>
	</li>
</xsl:template>
<xsl:template match="toc">
<div class="toc">
<ul>
<xsl:apply-templates select="../section" mode="summary"/>
</ul>
<p><img src="/btc.png"/>1HjZSXcwk6eHfJsvUA2hd6nVowimJrjdwp</p>
</div>
<br/>
<xsl:apply-templates select="../abstract" mode="show"/>
<xsl:apply-templates select="../keywords" mode="show"/>
</xsl:template>

<xsl:template match="package">
<p><xsl:apply-templates/>.</p>
</xsl:template>

<!-- #######################################################
	index document
-->
<xsl:template match="index">
<div class="index">
<table>
	<xsl:apply-templates/>
</table>
</div>
</xsl:template>
<xsl:template match="document">
<tr>
<td valign="top"><a href="{content/@file}">
	<xsl:value-of select="ref"/>
</a></td>
<td>
	<xsl:apply-templates select="title"/>
	<xsl:apply-templates select="att"/>
</td>
</tr>
</xsl:template>
<xsl:template match="att">
	<li><xsl:apply-templates/> <a href="{@file}">[Ouvrir]</a></li> 
</xsl:template>
<!-- #######################################################
	blog
-->
<xsl:template match="blog">
<div class="blog">
	<xsl:apply-templates select="document(@index)/blog/entry"/> 
</div>
</xsl:template>
<xsl:template match="entry">
<div class="blog-entry">
	<div class="blog-entry-head">
		<h2><xsl:value-of select="@title"/></h2>
		<p><xsl:value-of select="@author"/>, <xsl:value-of select="@date"/></p>
	</div>
	<div class="blog-entry-content">
		<xsl:apply-templates/>
	</div>
</div>
</xsl:template>

<!-- #######################################################
	en tete de page
-->
<xsl:template match="parent">
/ <a href="{@path}"><xsl:value-of select="@title"/></a>
</xsl:template>
<xsl:template match="subdir|subfile">
| <a href="{@path}"><xsl:value-of select="@title"/></a>
</xsl:template>
<xsl:template name="page-head">
	<xsl:param name="title"></xsl:param>
<div class="head">
	<xsl:apply-templates select="head"/>
<!--
<p>
<xsl:apply-templates select="document('../../.idx.xml')/path/parent"/>
<br/>
&#160;&#160;&#160;&#160;
<xsl:apply-templates select="document('../../.idx.xml')/path/subdir"/>
<xsl:apply-templates select="document('../../.idx.xml')/path/subfile"/>
 | <a href="mailto:sebastien.devaux@laposte.net?subject=[{$pageId}]">Ecrire</a>
</p>
-->
<h1><xsl:value-of select="$title"/></h1>
</div>
</xsl:template>
<!-- #######################################################
	corps de page
-->
<xsl:template name="page-body">
	<xsl:param name="content-template"></xsl:param>
<div class="body">
	<div class="popup" id="popupbox">&#160;</div>
<xsl:choose>
	<xsl:when test="$content-template='section'">
		<xsl:apply-templates select="toc|section|xhtml"/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:apply-templates/>
	</xsl:otherwise>
</xsl:choose>	
</div>
</xsl:template>
<!-- #######################################################
	pied de page
-->
<xsl:template name="page-foot">
<div class="foot">
<p><xsl:apply-templates select="/document/copyright"/><xsl:value-of select="$buildDate"/><br/><img src="btc.png"/>Donate: 1HjZSXcwk6eHfJsvUA2hd6nVowimJrjdwp</p>
</div>
</xsl:template>
<xsl:template match="copyright">
Copyright (c) <xsl:value-of select="./text()"/>,&#160;
</xsl:template>
<!-- #######################################################
	squelette page
-->
<xsl:template name="page">
	<xsl:param name="title"></xsl:param>
	<xsl:param name="content-template"></xsl:param>
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr" lang="fr">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<link rel="SHORTCUT ICON" href="{$root}/favicon.ico"/>
<title><xsl:value-of select="$title"/></title>
<xsl:apply-templates select="abstract"/>
<xsl:apply-templates select="keywords"/>
<style type="text/css">
@import url("<xsl:value-of select="$root"/>/style.css");
</style>
</head>	
<body>
	<a name="top"/>
<!-- en tete page -->
<xsl:call-template name="page-head">
	<xsl:with-param name="title"><xsl:value-of select="$title"/></xsl:with-param>
</xsl:call-template>
<!-- corps de la page -->
<xsl:call-template name="page-body">
	<xsl:with-param name="content-template"><xsl:value-of select="$content-template"/></xsl:with-param>
</xsl:call-template>
<!-- pied de page -->
<xsl:call-template name="page-foot"/>
</body>
</html>
</xsl:template>
<!-- #######################################################
	mapping root sur squelette page
-->
<xsl:template match="root">
	<xsl:call-template name="page">
		<xsl:with-param name="title" select="@title"/>
		<xsl:with-param name="content-template">all</xsl:with-param>
	</xsl:call-template>
</xsl:template>
<!-- #######################################################
	mapping document sur squelette page
-->
<xsl:template match="/document">
	<xsl:if test="count(section)&gt;0">
	<xsl:call-template name="page">
		<xsl:with-param name="title"><xsl:value-of select="@title"/></xsl:with-param>
		<xsl:with-param name="content-template">section</xsl:with-param>
	</xsl:call-template>
	</xsl:if>
</xsl:template>
<!--**********************************************
	sommaire
-->
<xsl:template match="document" mode="summary">
	<div class="toc">
	<xsl:param name="chapterFile"/>
	<xsl:param name="id"/>
	<h3><a href="{$chapterFile}"> Chapitre&#160;<xsl:value-of select="$id"/>&#160;: 
		&#160;<xsl:value-of select="title"/></a></h3>
	<xsl:if test="count(section)&gt;0">
		<ul><xsl:apply-templates select="section" mode="summary">
			<xsl:with-param name="chapterFile"><xsl:value-of select="$chapterFile"/></xsl:with-param>
		</xsl:apply-templates></ul>
	</xsl:if>
	</div>
</xsl:template>
<xsl:template match="summary/include">
	<xsl:apply-templates select="document(concat(@href,'.xml'),/)/document" mode="summary">
		<xsl:with-param name="chapterFile"><xsl:value-of select="@href"/>.html</xsl:with-param>
		<xsl:with-param name="id"><xsl:number count="include" format="I"/></xsl:with-param>
	</xsl:apply-templates>
</xsl:template>
</xsl:stylesheet>
